# 在Debian12上安装geoserver2.27

> wandoubaba / 2025-04-23

## 介绍

> GeoServer is a Java-based server that allows users to view and edit geospatial data. Using open standards set forth by the Open Geospatial Consortium (OGC), GeoServer allows for great flexibility in map creation and data sharing.


GeoServer 是一款基于 Java 的服务器，允许用户查看和编辑地理空间数据。通过遵循开放地理空间信息联盟（OGC）制定的开放标准，GeoServer 在地图创建和数据共享方面具有高度的灵活性。

## 环境

本次操作系统是Debian 12 Amd64，选择的GeoServer版本是2.27.0

## 操作

### 安装jdk

GeoServer官网描述，GeoServer需要JDK 11或JDK 17环境，在<https://openjdk.org/>上可以下载，我下载了JDK 21，安装GeoServer没有问题。

```sh
curl -O https://download.oracle.com/java/21/latest/jdk-21_linux-aarch64_bin.tar.gz
tar zxvf jdk-21_linux-aarch64_bin.tar.gz
sudo mv jdk-21.0.7 /usr/local/java
```

下面需要配置jdk环境变量：

```sh
vim /etc/profile.d/java.sh
```

添加如下内容：

```sh
export JAVA_HOME=/usr/local/java
export PATH=$JAVA_HOME/bin:$PATH
```

使配置生效：

```sh
source /etc/profile.d/java.sh
```

验证安装：

```sh
java -version
# java version "21.0.7" 2025-04-15 LTS ...
javac -version
# javac 21.0.7
```

### 安装GeoServer

```sh
curl -O https://jaist.dl.sourceforge.net/project/geoserver/GeoServer/2.27.0/geoserver-2.27.0-bin.zip?viasf=1
apt-get install -y unzip
unzip geoserver-2.27.0-bin.zip -d geoserver
mv geoserver /usr/share/geoserver
echo "export GEOSERVER_HOME=/usr/share/geoserver" >> /etc/profile.d/geoserver.sh
source /etc/profile.d/geoserver.sh
```

### 启动GeoServer

```sh
cd $GEOSERVER_HOME/bin
sh startup.sh
```

这时候等一会GeoServer服务就能启动了，启动成功后，在客户端浏览器访问下面的地址可以打开GeoServer的web管理界面

```plain
http://IP:8080/geoserver
```

### 处理因字体配置导致的报错

按照以上方法搭建的GeoServer服务，在访问Web管理界面时，会看到Java报错（点一下“服务器状态”），大概率是由于初始化中文字体配置时导致的问题，按照下面的步骤操作可以解决：

```sh
sudo apt-get install -y fontconfig libfontconfig1
sudo fc-cache -fv
```

### 登录Web界面

GeoServer的默认用户名是admin，默认密码是geoserver

### 系统服务与开机自启

在debian系统中，我使用systemd管理服务项

```sh
sudo vim /etc/systemd/system/geoserver.service
```

文件内容如下：

```ini
[Unit]
Description=GeoServer Geospatial Data Server
After=network.target
Wants=network.target

[Service]
Type=simple
WorkingDirectory=/usr/share/geoserver/bin
ExecStart=/usr/share/geoserver/bin/startup.sh
ExecStop=/usr/share/geoserver/bin/shutdown.sh
Restart=always
RestartSec=10
Environment="JAVA_HOME=/usr/local/java"
Environment="GEOSERVER_HOME=/usr/share/geoserver"

[Install]
WantedBy=multi-user.target
```

使配置生效：

```sh
sudo systemctl daemon-reload
sudo systemctl enable geoserver
sudo systemctl start geoserver
```

可以重启系统试一下，正常情况的可以在客户端直接打开Web管理界面。
